@@ -3,6 +3,7 @@
 #' The \code{plot()} method for the \code{performance::check_collinearity()} function.
 #'
 #' @inheritParams data_plot
+#' @inheritParams plot.see_check_normality
 #'
 #' @return A ggplot2-object.
 #'
@@ -14,14 +15,16 @@
 #' plot(result)
 #' @importFrom rlang .data
 #' @export
-plot.see_check_collinearity <- function(x, data = NULL, ...) {
+plot.see_check_collinearity <- function(x, data = NULL, colors = c("#3aaf85", "#1b6ca8", "#cd201f"), ...) {
   if (is.null(data)) {
     dat <- .compact_list(.retrieve_data(x))
   } else {
     dat <- data
   }
 
-  if (is.null(dat)) return(NULL)
+  if (is.null(dat)) {
+    return(NULL)
+  }
 
   dat$group <- "low"
   dat$group[dat$VIF >= 5 & dat$VIF < 10] <- "moderate"
@@ -39,6 +42,5 @@ plot.see_check_collinearity <- function(x, data = NULL, ...) {
     dat <- dat[, -which(colnames(dat) == "facet")]
   }
 
-  .plot_diag_vif(dat)
+  .plot_diag_vif(dat, colors = colors)
 }
-
