@@ -4,7 +4,10 @@
 #'
 #' @param type Character vector, indicating the type of plot.
 #' @param size_line Size of line geoms.
-#' @param alpha ALpha level of the confidence bands.
+#' @param dot_alpha,alpha ALpha level of the confidence bands and point-geoms.
+#' @param colors Character vector of length two, indicating the colors (in
+#'   hex-format) for points and line.
+#' @param detrend Should the plot be detrended?
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
 #'
@@ -18,7 +21,7 @@
 #' @importFrom bayestestR estimate_density
 #' @importFrom stats residuals sd dnorm rstudent ppoints pnorm fitted
 #' @export
-plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data = NULL, size_line = .8, size_point = 2, alpha = .2, ...) {
+plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data = NULL, size_line = .8, size_point = 2, alpha = .2, dot_alpha = .8, colors = c("#3aaf85", "#1b6ca8"), detrend = FALSE, ...) {
   type <- match.arg(type)
 
   if (is.null(data)) {
@@ -39,7 +42,7 @@ plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data =
       }
 
       dat <- stats::na.omit(data.frame(y = res_))
-      .plot_diag_qq(dat, size_point = size_point, size_line = size_line, alpha_level = alpha)
+      .plot_diag_qq(dat, size_point = size_point, size_line = size_line, alpha_level = alpha, detrend = detrend, dot_alpha_level = dot_alpha)
     } else if (type == "density") {
       r <- stats::residuals(model)
       dat <- as.data.frame(bayestestR::estimate_density(r))
@@ -52,8 +55,7 @@ plot.see_check_normality <- function(x, type = c("density", "qq", "pp"), data =
     } else if (type == "pp") {
       x <- sort(stats::residuals(model), na.last = NA)
       dat <- data.frame(res = x)
-      .plot_diag_pp(dat, size_point = size_point, size_line = size_line, alpha_level = alpha)
+      .plot_diag_pp(dat, size_point = size_point, size_line = size_line, alpha_level = alpha, detrend = detrend, dot_alpha_level = dot_alpha)
     }
   }
 }
-
