@@ -26,23 +26,21 @@
 #'     theme_radar()
 #' }
 #' @export
-theme_radar <- function(
-  base_size = 11,
-  base_family = "",
-  plot.title.size = 12,
-  plot.title.face = "plain",
-  plot.title.space = 15,
-  legend.position = "right",
-  axis.title.space = 15,
-  legend.title.size = 11,
-  legend.text.size = 10,
-  axis.title.size = 11,
-  axis.title.face = "plain",
-  axis.text.size = 10,
-  axis.text.angle = NULL,
-  tags.size = 11,
-  tags.face = "plain") {
-
+theme_radar <- function(base_size = 11,
+                        base_family = "",
+                        plot.title.size = 12,
+                        plot.title.face = "plain",
+                        plot.title.space = 15,
+                        legend.position = "right",
+                        axis.title.space = 15,
+                        legend.title.size = 11,
+                        legend.text.size = 10,
+                        axis.title.size = 11,
+                        axis.title.face = "plain",
+                        axis.text.size = 10,
+                        axis.text.angle = NULL,
+                        tags.size = 11,
+                        tags.face = "plain") {
   theme_modern(
     base_size = base_size,
     base_family = base_family,
@@ -61,39 +59,37 @@ theme_radar <- function(
     tags.face = tags.face
   ) +
     theme(
-      axis.line        = element_blank(),
-      axis.text        = element_text(colour = "grey20"),
-      axis.title       = element_text(colour = "grey10"),
+      axis.line = element_blank(),
+      axis.text = element_text(colour = "grey20"),
+      axis.title = element_text(colour = "grey10"),
       strip.background = element_rect(colour = "grey70", fill = "grey90"),
-      strip.text       = element_text(colour = "grey20"),
-      legend.title     = element_text(colour = "grey20"),
-      legend.text      = element_text(colour = "grey25"),
+      strip.text = element_text(colour = "grey20"),
+      legend.title = element_text(colour = "grey20"),
+      legend.text = element_text(colour = "grey25"),
       panel.grid.major = element_line(colour = "grey80"),
       panel.grid.minor = element_line(colour = "grey90"),
-      panel.border     = element_blank()
+      panel.border = element_blank()
     )
 }
 
 
 #' @rdname theme_radar
 #' @export
-theme_radar_dark <- function(
-  base_size = 11,
-  base_family = "",
-  plot.title.size = 12,
-  plot.title.face = "plain",
-  plot.title.space = 15,
-  legend.position = "right",
-  axis.title.space = 15,
-  legend.title.size = 11,
-  legend.text.size = 10,
-  axis.title.size = 11,
-  axis.title.face = "plain",
-  axis.text.size = 10,
-  axis.text.angle = NULL,
-  tags.size = 11,
-  tags.face = "plain") {
-
+theme_radar_dark <- function(base_size = 11,
+                             base_family = "",
+                             plot.title.size = 12,
+                             plot.title.face = "plain",
+                             plot.title.space = 15,
+                             legend.position = "right",
+                             axis.title.space = 15,
+                             legend.title.size = 11,
+                             legend.text.size = 10,
+                             axis.title.size = 11,
+                             axis.title.face = "plain",
+                             axis.text.size = 10,
+                             axis.text.angle = NULL,
+                             tags.size = 11,
+                             tags.face = "plain") {
   theme_modern(
     base_size = base_size,
     base_family = base_family,
@@ -120,6 +116,6 @@ theme_radar_dark <- function(
       axis.text = element_text(color = "#f2f2f2"),
       panel.grid.major = element_line(color = "#465463"),
       strip.text = element_text(color = "#f2f2f2"),
-      panel.border     = element_blank()
+      panel.border = element_blank()
     )
 }
